YARP 3.4.1 (2020-09-28)                                                {#v3_4_1}
=======================

[TOC]

YARP 3.4.1 Release Notes
========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v3.4.1%22).



* Fixed Ruby bindings with CMake 3.18


Bug Fixes
---------

### Build System

* The license check is now disabled for non-git checkouts.
* The check on the bindings folder in `YARPConfig.cmake` was removed.
* User defined build flags are no longer overridden in subfolders.
* The `-f(debug|macro|file)-prefix-map` compile options are no longer exported
  in the `YARPConfig.cmake` file.
* Fixed build when the `-fsanitize` compile options is passed by the user.

### Libraries

#### `os`

##### `Stamp`

* Fixed the max count using std::numeric_limits.


#### `sig`

##### `PointCloudUtils`

* Fixed `yarp::sig::utils::depthRgbToPC` for types without alpha channel
  (#1959).
* Fixed bug in method `utils::depthToPC()` which was not properly decimating the
  pointcloud given in input.


### Devices

#### `FakeFrameGrabber`

* The ball test is now displayed in the center of the image instead of the
  right-bottom corner. The bug was affecting windows only.

#### `multipleanalogsensorsserver`

* Fixed missing timestamp and and sequence number in messages streamed by
  `measures:o` port.

#### `realsense2Tracking`

* Fixed missing timestamp for device `realsense2Tracking`
* added option `--timestamp yarp` : yarp timestamp will be used
* added option `--timestamp realsense` : realsense timestamp will be used
* default value is `yarp timestamp`.

#### `ovrheadset`

* Fixed a typo in `TextureBuffer.cpp`

### Tools

#### `yarpdatadumper`

* Fixed a regression that broke support for OpenCV 2.x.

#### `yarpmanager`

* Fixed issue that disables side menubar buttons when changing tab (#2355).

#### `yarprobotinterface`

* Fixed build on i386.


Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v3.4.0..v3.4.1`):
```
    43	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     7	Nicolò Genesio <nicolo.genesio@iit.it>
     5	Marco Randazzo <marco.randazzo@iit.it>
     2	Bartek Łukawski <bwmn.peter@gmail.com>
     2	Stefano Dafarra <stefano.dafarra@iit.it>
     1	Silvio Traversaro <silvio.traversaro@iit.it>
```
